MissingOverlayHostException class

Exception thrown when an AnchoredOverlayEngineHost is required but not found.

This is a programming error - the component requires a host ancestor to function. Unlike asserts, this exception is thrown in release mode to provide diagnostics.

Implemented types

Constructors

MissingOverlayHostException({required String componentName})
const

Properties

componentName String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited